## Introduction

**aos Cube** is the name of the aos developing manage tools, packaged as aos-cube, which enables the full aos workflow: repositories version control, maintaining dependencies, publishing code, updating from remotely hosted repositories and invoking aos's own build system and export functions, among other operations.

Select language:
* [English](doc/english/README.md)
* [Chinese](doc/chinese/README.md)
